package com.miaxis.pc.controller;

import com.miaxis.common.constant.Constants;
import java.util.List;
import java.util.Arrays;

import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.order.domain.OrderItems;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.order.domain.OrderInfo;
import com.miaxis.order.service.IOrderInfoService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【订单】Controller
 *
 * @author miaxis
 * @date 2023-11-17
 */
@RestController
@RequestMapping("/order/info")
@Api(tags={"【pc-订单】"})
public class OrderInfoController extends BaseController{
    @Autowired
    private IOrderInfoService orderInfoService;

    /**
     * 查询订单列表
     */
    @PreAuthorize("@ss.hasPermi('order:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询订单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<OrderInfo> list(@ModelAttribute OrderInfo orderInfo){
        startPage();
        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 导出订单列表
     */
    @PreAuthorize("@ss.hasPermi('order:info:export')")
    @Log(title = "订单", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出订单列表Excel")
    public Response<String> export(@ModelAttribute OrderInfo orderInfo){
        List<OrderInfo> list = orderInfoService.selectOrderInfoList(orderInfo);
        ExcelUtil<OrderInfo> util = new ExcelUtil<OrderInfo>(OrderInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取订单详细信息")
    public Response<OrderInfo> getInfo(
            @ApiParam(name = "id", value = "订单参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(orderInfoService.getById(id));
    }

    /**
     * 新增订单
     */
    @PreAuthorize("@ss.hasPermi('order:info:add')")
    @Log(title = "订单", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增订单")
    public Response add(@RequestBody List<OrderItems> orderItemsList){
        orderInfoService.addOrder(orderItemsList);
        return Response.success();
}

    /**
     * 修改订单
     */
    @PreAuthorize("@ss.hasPermi('order:info:edit')")
    @Log(title = "订单", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改订单")
    public Response<Integer> edit(@RequestBody OrderInfo orderInfo){
        return toResponse(orderInfoService.updateById(orderInfo) ? 1 : 0);
    }

    /**
     * 删除订单
     */
    @PreAuthorize("@ss.hasPermi('order:info:remove')")
    @Log(title = "订单", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除订单")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "订单ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(orderInfoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
