package com.miaxis.order.service.impl;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.miaxis.common.utils.DateUtils;
import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.order.domain.OrderItems;
import com.miaxis.order.service.IOrderItemsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.apache.commons.lang3.StringUtils;
import com.miaxis.order.mapper.OrderInfoMapper;
import com.miaxis.order.domain.OrderInfo;
import com.miaxis.order.service.IOrderInfoService;

/**
 * 订单Service业务层处理
 *
 * @author miaxis
 * @date 2023-11-17
 */
@Service
public class OrderInfoServiceImpl extends ServiceImpl<OrderInfoMapper, OrderInfo> implements IOrderInfoService {
    @Autowired
    private OrderInfoMapper orderInfoMapper;

    @Autowired
    private IOrderItemsService orderItemsService;

    /**
     * 查询订单列表
     *
     * @param orderInfo 订单
     * @return 订单
     */
    @Override
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo){
        return orderInfoMapper.selectOrderInfoList(orderInfo);
    }

    @Override
    public void addOrder(List<OrderItems> orderItemsList) {
        OrderInfo orderInfo = new OrderInfo();
        orderInfo.setBusinessName(SecurityUtils.getUsername());
        orderInfo.setStatus(0);
        orderInfo.setOrderNo(createOrderNo());
        this.save(orderInfo);
        orderItemsList.stream().forEach(o->o.setOrderNo(orderInfo.getOrderNo()));
        orderItemsService.saveBatch(orderItemsList);
    }

    private String createOrderNo() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
        String orderNoPrefix ="KM-JZ"+ sdf.format(new Date());
        List<OrderInfo> list = this.list(new QueryWrapper<OrderInfo>().like("order_no", orderNoPrefix).orderByDesc("create_time"));
        if(CollectionUtils.isNotEmpty(list)){
            OrderInfo orderInfo = list.get(0);
            String count = orderInfo.getOrderNo().replace(orderNoPrefix, "");
            String newOrderNo = orderNoPrefix+ (Integer.valueOf(count)+1);
            return newOrderNo;
        }else{
            return orderNoPrefix+1;
        }


    }
}
